@@ -1,8 +1,15 @@
+from click.testing import CliRunner
 from pytest import fixture
+
 from tests.example_command import make_example_command
 from tests.example_group import make_example_group
 
 
+@fixture()
+def runner():
+    return CliRunner()
+
+
 @fixture(scope='session')
 def get_example_command():
     aligned_cmd = make_example_command(align_option_groups=True)
